###Installation
```pip install weather-forcaster```
###Usage
###Input
```
import weather-forecaster as wf
wf.forecast("india","delhi")
```
###Output
```
Scraping Weather Data
---------------------
Temperature: 39 °C
Climate: Haze
Location: New Delhi / Safdarjung
Current Time: 10 Jun 2021, 17:20:18
Latest Report: 10 Jun 2021, 14:30
Visibility: 4 km
Pressure: 995 mbar
Humidity: 46%
Dew Point: 25 °C
```